@@ -53,6 +53,7 @@ LOGGER = logging.getLogger('BigML')
 
 import sys
 import locale
+import json
 
 from bigml.api import FINISHED
 from bigml.api import (BigML, get_model_id, get_status)
@@ -109,10 +110,12 @@ def print_distribution(distribution, out=sys.stdout):
     total = reduce(lambda x, y: x + y,
                    [group[1] for group in distribution])
     for group in distribution:
-        out.write(utf8(u"    %s: %.2f%% (%d instance%s)\n" % (group[0],
-                       round(group[1] * 1.0 / total, 4) * 100,
-                       group[1],
-                       "" if group[1] == 1 else "s")))
+        out.write(utf8(
+            u"    %s: %.2f%% (%d instance%s)\n" % (
+                group[0],
+                round(group[1] * 1.0 / total, 4) * 100,
+                group[1],
+                "" if group[1] == 1 else "s")))
 
 
 class Model(BaseModel):
@@ -124,26 +127,52 @@ class Model(BaseModel):
     """
 
     def __init__(self, model, api=None):
+        """The Model constructor can be given as first argument:
+            - a model structure
+            - a model id
+            - a path to a JSON file containing a model structure
+
+        """
+        # the string can be a path to a JSON file
+        if isinstance(model, basestring):
+            try:
+                with open(model) as model_file:
+                    model = json.load(model_file)
+                    self.resource_id = get_model_id(model)
+                    if self.resource_id is None:
+                        raise ValueError("The JSON file does not seem"
+                                         " to contain a valid BigML model"
+                                         " representation.")
+            except IOError:
+                # if it is not a path, it can be a model id
+                self.resource_id = get_model_id(model)
+                if self.resource_id is None:
+                    if model.find('model/') > -1:
+                        raise Exception(
+                            api.error_message(model,
+                                              resource_type='model',
+                                              method='get'))
+                    else:
+                        raise IOError("Failed to open the expected JSON file"
+                                      " at %s" % model)
+            except ValueError:
+                raise ValueError("Failed to interpret %s."
+                                 " JSON file expected.")
 
         if not (isinstance(model, dict) and 'resource' in model and
                 model['resource'] is not None):
             if api is None:
                 api = BigML(storage=STORAGE)
-            self.resource_id = get_model_id(model)
-            if self.resource_id is None:
-                raise Exception(api.error_message(model,
-                                                  resource_type='model',
-                                                  method='get'))
             query_string = ONLY_MODEL
             model = retrieve_resource(api, self.resource_id,
                                       query_string=query_string)
         BaseModel.__init__(self, model, api=api)
-        if ('object' in model and isinstance(model['object'], dict)):
+        if 'object' in model and isinstance(model['object'], dict):
             model = model['object']
 
-        if ('model' in model and isinstance(model['model'], dict)):
+        if 'model' in model and isinstance(model['model'], dict):
             status = get_status(model)
-            if ('code' in status and status['code'] == FINISHED):
+            if 'code' in status and status['code'] == FINISHED:
                 distribution = model['model']['distribution']['training']
                 self.ids_map = {}
                 self.tree = Tree(
@@ -182,7 +211,11 @@ class Model(BaseModel):
 
     def predict(self, input_data, by_name=True,
                 print_path=False, out=sys.stdout, with_confidence=False,
-                missing_strategy=LAST_PREDICTION):
+                missing_strategy=LAST_PREDICTION,
+                add_confidence=False,
+                add_rules=False,
+                add_distribution=False,
+                add_instances=False):
         """Makes a prediction based on a number of field values.
 
         By default the input fields must be keyed by field name but you can use
@@ -211,9 +244,22 @@ class Model(BaseModel):
         if print_path:
             out.write(utf8(u' AND '.join(path) + u' => %s \n' % prediction))
             out.flush()
+        output = prediction
         if with_confidence:
-            return [prediction, confidence, distribution, instances]
-        return prediction
+            output = [prediction, confidence, distribution, instances]
+        if add_confidence or add_rules or add_distribution or add_instances:
+            output = {'prediction': prediction}
+            if add_confidence:
+                output.update({'confidence': confidence})
+            if add_rules:
+                rules = [] if missing_strategy == PROPORTIONAL else path
+                output.update({'rules': rules})
+            if add_distribution:
+                output.update({'distribution': distribution})
+            if add_instances:
+                output.update({'instances': instances})
+
+        return output
 
     def docstring(self):
         """Returns the docstring describing the model.
@@ -222,11 +268,12 @@ class Model(BaseModel):
         docstring = (u"Predictor for %s from %s\n" % (
             self.fields[self.tree.objective_id]['name'],
             self.resource_id))
-        self.description = (unicode(markdown_cleanup(
-            self.description).strip())
-            or u'Predictive model by BigML - Machine Learning Made Easy')
-        docstring += u"\n" + INDENT * 2 + (u"%s" %
-                     prefix_as_comment(INDENT * 2, self.description))
+        self.description = (
+            unicode(
+                markdown_cleanup(self.description).strip()) or
+            u'Predictive model by BigML - Machine Learning Made Easy')
+        docstring += u"\n" + INDENT * 2 + (
+            u"%s" % prefix_as_comment(INDENT * 2, self.description))
         return docstring
 
     def get_ids_path(self, filter_id):
@@ -366,7 +413,7 @@ class Model(BaseModel):
         tree = self.tree
         distribution = tree.distribution
 
-        return sorted(distribution,  key=lambda x: x[0])
+        return sorted(distribution, key=lambda x: x[0])
 
     def get_prediction_distribution(self, groups=None):
         """Returns model predicted distribution
@@ -379,7 +426,7 @@ class Model(BaseModel):
         # remove groups that are not predicted
         predictions = filter(lambda x: x[1] > 0, predictions)
 
-        return sorted(predictions,  key=lambda x: x[0])
+        return sorted(predictions, key=lambda x: x[0])
 
     def summarize(self, out=sys.stdout):
         """Prints summary grouping distribution as class header and details
@@ -512,8 +559,9 @@ class CSVInput(object):
             self.reader = csv.reader(input, delimiter=',', quotechar='\"')
 """ % ",".join(parameters)
 
-        output += (u"\n%sself.INPUT_FIELDS = [%s]\n" %
-                  ((INDENT * 3), (",\n " + INDENT * 8).join(args)))
+        output += (
+            u"\n%sself.INPUT_FIELDS = [%s]\n" %
+            ((INDENT * 3), (",\n " + INDENT * 8).join(args)))
 
         input_types = []
         prefixes = []
